import sys
import argparse

from modularity.module_generator import ModuleGenerator
from modularity.oc_template import OpenShiftTemplateGenerator


class ModtoolsCLI(object):
    """ Class for processing data from commandline """

    @staticmethod
    def build_parser():
        parser = argparse.ArgumentParser(description="Generates module related files")
        subparsers = parser.add_subparsers(dest="cmd_name")

        parser_rpm2module = subparsers.add_parser(
            'rpm2module', help="Generates modulemd file",
            description="Gets package info and dependencies and creates modulemd file."
        )
        parser_rpm2module.add_argument(
            "pkgs",
            metavar='PKGS',
            nargs='+',
            help="Specify list of packages for module.",
        )

        parser_docker2openshift = subparsers.add_parser(
            "docker2openshift", help="Generates openshift template from dockerfile",
            description="Creates an OpenShift template YAML file.",
        )

        parser_docker2openshift.add_argument(
            "image",
            metavar='IMAGE',
            help="docker image name (like NAME or docker.io/USER/NAME)",
        )
        parser_docker2openshift.add_argument(
            "--dockerfile",
            help="Specify Dockerfile name. Default is Dockerfile."
        )

        return parser

    def __init__(self, args=None):
        self.parser = ModtoolsCLI.build_parser()
        self.args = self.parser.parse_args(args)

    def __getattr__(self, name):
        try:
            return getattr(self.args, name)
        except AttributeError:
            return object.__getattribute__(self, name)


class ModtoolsCLIHelper(object):

    @staticmethod
    def run():
        try:
            cli = ModtoolsCLI(sys.argv[1:])
            if cli.args.cmd_name == 'rpm2module':
                mg = ModuleGenerator(cli.args.pkgs)
                mg.run()

            if cli.args.cmd_name == 'docker2openshift':
                otg = OpenShiftTemplateGenerator(cli.args)
                otg.run()
        except KeyboardInterrupt:
            print('\nInterrupted by user')
        except Exception as e:
            print(e)
            sys.exit(1)
